; inc_ConfigTools.ahk
; has labels and functions for configuring language tools.

InitLangTools:
; sets tools from ini file or asks user for directroy if not tools not found
    IniRead, gToolPath, %kIniFile%, %kToolSection%, %kToolPathKey%  ; get stuff from ini file
    IfNotExist %gToolPath%\%kCompileTool%.exe     	; if gToolPath does not produce good tools,
        gosub ConfigFirstUse                    	; then ask for a new folder, etc.
    IfNotExist %gToolPath%\%kInterpreterTool%.exe
        gosub ConfigFirstUse
    return

ConfigFirstUse:
; guides user through first-time jIDEE configuration.
; TODO: make GUI strings here variables initialized in inc_GiuStrings?

;================;
; define strings ;
;================;

kConfigFirstUseMsgTitle = Hello, first timer!
kConfigFirstUseMsgTxt =
(
This looks like the first time you are using jIDEE.

Before you are able to use jIDEE, we need to configure a couple things: 
1) Your first project folder.
2) Your Java tools.

The next few screens will help you set this up.
)

kConfigDefaultRootMsgTitle = Set a root project folder
kConfigDefaultRootMsgTxt =
(
jIDEE assumes you organize your work in project folders.

I strongly recommend that you set or create at least one unique folder to use as a project folder.
It's ok to make this inside "My Documents", but you should not use "My Documents" as a project folder.
If your "My Documents" folder has a lot of subfoders, it will take a really long time for jIDEE to initialize. 

Do you want to configure a new project folder now?
(You should probably say "Yes".)
)

kConfigToolsMsgTitle = Setting the JDK...
kConfigToolsMsgTxt =
(
Now you need to tell me where the Java Development Kit (JDK) binaries are on your system.
(You will only have to do this once, unless you change your system.)

The JDK binaries are typically in a location like "C:\Program Files\Java\jdk1.6.x_xx\bin".
Be sure that you tell me the location of the Java Development Kit (JDK) binaries -- not the Java Runtime Environment (JRE) binaries! 

When you click OK, I will ask you to navigate to the folder where the JDK binaries are stored. After that you should be all set.
)

;============;
; make it go ;
;============;

	MsgBox, 64, %kConfigFirstUseMsgTitle%, %kConfigFirstUseMsgTxt%			; ok, icon info
	MsgBox, 36, %kConfigDefaultRootMsgTitle%, %kConfigDefaultRootMsgTxt%	; yes/no, icon question
	IfMsgBox Yes
		gosub InitNewRootName
	
	MsgBox, 64, %kConfigToolsMsgTitle%, %kConfigToolsMsgTxt%	; ok, icon info
	gosub SetJavaToolDir
	return	

SetJavaToolDir:
; prompt for a directory with Java tools and don't stop until we get one.
; note: canceling will quit the app
    Loop
    {
		IfExist, %A_ProgramFiles%\Java\
			gTempDirName = %A_ProgramFiles%\Java\
		Else
			gTempDirName = %A_ProgramFiles%
		; prompt for and set new working dir, update (rebuild) file lists and update working dir text on main gui
        Gui +OwnDialogs  ; Forces user to dismiss the following dialog before using main window.
        FileSelectFolder, gTempDirName, *%gTempDirName%, 0, %kSetJDKTools%
        if not gTempDirName  ; The user canceled the dialog.
        	gosub Quit
        IfExist %gTempDirName%\%kCompileTool%.exe
        {
            IfExist %gTempDirName%\%kInterpreterTool%.exe
            {
                gToolPath = %gTempDirName%		; set tool path
                IniWrite, %gToolPath%, %kIniFile%, %kToolSection%, %kToolPathKey% 	; save new path and tool names to ini file
                break   ; terminate the loop
            }
        }
    }
    return

InitNewRootName:
; prompt for new root dir, set gRootDir to new directory
; TODO move GUI sting to GUI string files
	Gui +OwnDialogs	; Forces user to dismiss the following dialog before using main window.
	FileSelectFolder, gTempDirName, *%gRootDir%, 1, %kChangeRootFolder%
	if not gTempDirName		; The user canceled the dialog.
		return
	; if user selected a root drive, give message and return
	SplitPath, gTempDirName, projectRootName,,,, 	; if user selected a root drive, projectRootName will be blank 
	if projectRootName
		gRootDir = %gTempDirName%
	else
	{
		msgbox Root drives cannot be used as project roots.`nSelect a different folder as your project root.
		gosub ChangeRootDir			; recurse.
	}
	return
